Author: ekohl
Date: Tue Dec 22 18:00:45 2009
New Revision: 44716
URL: http://svn.reactos.org/svn/reactos?rev=44716&view=rev
Log:
If the user doubleclicked a treeview item, make sure the doubleclicked item has already been selected. Otherwise the user can expand or collapse a treeview iten and a previously selected item get opened. That's not what we want.
Modified:
trunk/reactos/base/applications/mscutils/devmgmt/mainwnd.c
Modified: trunk/reactos/base/applications/mscutils/devmgmt/mainwnd.c
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/base/applications/mscutils…
==============================================================================
--- trunk/reactos/base/applications/mscutils/devmgmt/mainwnd.c [iso-8859-1] (original)
+++ trunk/reactos/base/applications/mscutils/devmgmt/mainwnd.c [iso-8859-1] Tue Dec 22 18:00:45 2009
@@ -342,12 +342,21 @@
case NM_DBLCLK:
{
HTREEITEM hSelected = TreeView_GetSelection(Info->hTreeView);
+ TV_HITTESTINFO HitTest;
if (!TreeView_GetChild(Info->hTreeView,
hSelected))
{
- OpenPropSheet(Info->hTreeView,
- hSelected);
+ if (GetCursorPos(&HitTest.pt) &&
+ ScreenToClient(Info->hTreeView, &HitTest.pt))
+ {
+ if (TreeView_HitTest(Info->hTreeView, &HitTest))
+ {
+ if (HitTest.hItem == hSelected)
+ OpenPropSheet(Info->hTreeView,
+ hSelected);
+ }
+ }
}
}
break;
Author: ekohl
Date: Tue Dec 22 17:57:27 2009
New Revision: 44714
URL: http://svn.reactos.org/svn/reactos?rev=44714&view=rev
Log:
Fix a typo. Use lpStartServiceName instead of lpServiceName.
This fixes two winetests.
Modified:
trunk/reactos/base/system/services/rpcserver.c
Modified: trunk/reactos/base/system/services/rpcserver.c
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/base/system/services/rpcse…
==============================================================================
--- trunk/reactos/base/system/services/rpcserver.c [iso-8859-1] (original)
+++ trunk/reactos/base/system/services/rpcserver.c [iso-8859-1] Tue Dec 22 17:57:27 2009
@@ -1969,8 +1969,9 @@
goto done;
}
- /* If a non driver and NULL for lpServiceName, write ObjectName as LocalSystem */
- if ((dwServiceType & SERVICE_WIN32) && (!lpServiceName))
+ /* FIXME: Handle lpServiceStartName propertly! */
+ /* If a non driver and NULL for lpServiceStartName, write ObjectName as LocalSystem */
+ if ((dwServiceType & SERVICE_WIN32) && (!lpServiceStartName))
{
dwError = RegSetValueExW(hServiceKey,
L"ObjectName",